@@ -697,9 +697,10 @@ xfdesktop_settings_update_iconview_frame_name(AppearancePanel *panel,
 
     g_return_if_fail(panel->monitor >= 0 && panel->workspace >= 0);
 
+    screen = wnck_window_get_screen(panel->wnck_window);
+
     /* If it's a pinned window get the active workspace */
     if(wnck_workspace == NULL) {
-        screen = wnck_window_get_screen(panel->wnck_window);
         workspace = wnck_screen_get_workspace(screen, panel->active_workspace);
     } else {
         workspace = wnck_workspace;
@@ -744,7 +745,8 @@ xfdesktop_settings_update_iconview_frame_name(AppearancePanel *panel,
             gtk_widget_set_visible(panel->infobar, TRUE);
         }
     } else {
-        if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(panel->chk_apply_to_all))) {
+        if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(panel->chk_apply_to_all)) ||
+           (wnck_screen_get_workspace_count(screen) == 1)) {
             /* Single monitor and single workspace */
             g_snprintf(buf, sizeof(buf), _("Wallpaper for my desktop"));
 
@@ -786,7 +788,7 @@ xfdesktop_settings_generate_per_workspace_binding_string(AppearancePanel *panel,
                               property);
     }
 
-    DBG("name %s", buf);
+    XF_DEBUG("name %s", buf);
 
     return buf;
 }
@@ -800,7 +802,7 @@ xfdesktop_settings_generate_old_binding_string(AppearancePanel *panel,
     buf = g_strdup_printf("/backdrop/screen%d/monitor%d/%s",
                           panel->screen, panel->monitor, property);
 
-    DBG("name %s", buf);
+    XF_DEBUG("name %s", buf);
 
     return buf;
 }
@@ -870,18 +872,18 @@ cb_image_selection_changed(GtkIconView *icon_view,
     /* check to see if the selection actually did change */
     if(g_strcmp0(current_filename, filename) != 0) {
         if(panel->monitor_name == NULL) {
-            DBG("got %s, applying to screen %d monitor %d workspace %d", filename,
-                panel->screen, panel->monitor, panel->workspace);
+            XF_DEBUG("got %s, applying to screen %d monitor %d workspace %d", filename,
+                     panel->screen, panel->monitor, panel->workspace);
         } else {
-            DBG("got %s, applying to screen %d monitor %s workspace %d", filename,
-                panel->screen, panel->monitor_name, panel->workspace);
+            XF_DEBUG("got %s, applying to screen %d monitor %s workspace %d", filename,
+                     panel->screen, panel->monitor_name, panel->workspace);
         }
 
         /* Get the property location to save our changes, always save to new
          * location */
         buf = xfdesktop_settings_generate_per_workspace_binding_string(panel,
                                                                        "last-image");
-        DBG("Saving to %s/%s", buf, filename);
+        XF_DEBUG("Saving to %s/%s", buf, filename);
         xfconf_channel_set_string(panel->channel, buf, filename);
     }
 
@@ -1031,6 +1033,8 @@ xfdesktop_spin_icon_size_timer(GtkSpinButton *button)
                             DESKTOP_ICONS_ICON_SIZE_PROP,
                             gtk_spin_button_get_value(button));
 
+    g_object_set_data(G_OBJECT(button), "timer-id", NULL);
+
     return FALSE;
 }
 
@@ -1118,7 +1122,7 @@ cb_folder_selection_changed(GtkWidget *button,
          * button to something then it can't be changed with a set folder
          * call anymore. */
         if(g_strcmp0(filename, dirname) == 0) {
-            DBG("folder didn't change");
+            XF_DEBUG("folder didn't change");
             g_free(dirname);
             g_free(filename);
             g_free(previous_filename);
@@ -1231,7 +1235,7 @@ xfdesktop_settings_update_iconview_folder(AppearancePanel *panel)
     current_folder = xfdesktop_settings_get_backdrop_image(panel);
     dirname = g_path_get_dirname(current_folder);
 
-    DBG("current_folder %s, dirname %s", current_folder, dirname);
+    XF_DEBUG("current_folder %s, dirname %s", current_folder, dirname);
 
     gtk_file_chooser_set_current_folder((GtkFileChooser*)panel->btn_folder, dirname);
 
@@ -1322,12 +1326,12 @@ xfdesktop_settings_background_tab_change_bindings(AppearancePanel *panel,
         /* If the first color doesn't exist, try to load the old one */
         if(!xfconf_channel_has_property(channel, buf)) {
             GValue value = { 0, };
-            old_property = xfdesktop_settings_generate_old_binding_string(panel, "color2");
+            old_property = xfdesktop_settings_generate_old_binding_string(panel, "color1");
 
             xfconf_channel_get_property(channel, old_property, &value);
 
             if(G_VALUE_HOLDS_BOXED(&value)) {
-                gtk_color_button_set_color(GTK_COLOR_BUTTON(panel->color2_btn),
+                gtk_color_button_set_color(GTK_COLOR_BUTTON(panel->color1_btn),
                                            g_value_get_boxed(&value));
                 g_value_unset(&value);
             } else {
@@ -1357,12 +1361,12 @@ xfdesktop_settings_background_tab_change_bindings(AppearancePanel *panel,
         /* If the 2nd color doesn't exist, try to load the old one */
         if(!xfconf_channel_has_property(channel, buf)) {
             GValue value = { 0, };
-            old_property = xfdesktop_settings_generate_old_binding_string(panel, "color1");
+            old_property = xfdesktop_settings_generate_old_binding_string(panel, "color2");
 
             xfconf_channel_get_property(channel, old_property, &value);
 
             if(G_VALUE_HOLDS_BOXED(&value)) {
-                gtk_color_button_set_color(GTK_COLOR_BUTTON(panel->color1_btn),
+                gtk_color_button_set_color(GTK_COLOR_BUTTON(panel->color2_btn),
                                            g_value_get_boxed(&value));
                 g_value_unset(&value);
             } else {
@@ -1497,7 +1501,7 @@ cb_update_background_tab(WnckWindow *wnck_window,
 
     /* remove the old bindings if there are any */
     if(panel->color1_btn_id || panel->color2_btn_id) {
-        DBG("removing old bindings");
+        XF_DEBUG("removing old bindings");
         xfdesktop_settings_background_tab_change_bindings(panel,
                                                           TRUE);
     }
@@ -1552,7 +1556,7 @@ cb_workspace_changed(WnckScreen *screen,
     if(new_num != -1)
         panel->active_workspace = new_num;
 
-    DBG("active_workspace now %d", panel->active_workspace);
+    XF_DEBUG("active_workspace now %d", panel->active_workspace);
 
     /* Call cb_update_background_tab in case this is a pinned window */
     if(panel->wnck_window != NULL)
@@ -1591,7 +1595,7 @@ cb_window_opened(WnckScreen *screen,
     if(wnck_window_get_xid(window) != GDK_WINDOW_XID(gtk_widget_get_window(toplevel)))
         return;
 
-    DBG("Found our window");
+    XF_DEBUG("Found our window");
     panel->wnck_window = window;
 
     /* These callbacks are for updating the image_iconview when the window
@@ -1697,6 +1701,7 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
     GdkScreen *screen;
     WnckScreen *wnck_screen;
     XfconfChannel *channel = panel->channel;
+    GdkColor color;
 
     TRACE("entering");
 
@@ -1726,6 +1731,7 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
     chk_custom_font_size = GTK_WIDGET(gtk_builder_get_object(main_gxml,
                                                              "chk_custom_font_size"));
     spin_font_size = GTK_WIDGET(gtk_builder_get_object(main_gxml, "spin_font_size"));
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_font_size), 12);
 
     /* single click */
     chk_single_click = GTK_WIDGET(gtk_builder_get_object(main_gxml,
@@ -1805,6 +1811,8 @@ xfdesktop_settings_dialog_setup_tabs(GtkBuilder *main_gxml,
                                                        "infobar_header"));
 
     panel->infobar_label = gtk_label_new("This is some text");
+    gdk_color_parse ("black", &color);
+    gtk_widget_modify_fg (panel->infobar_label, GTK_STATE_NORMAL, &color);
     gtk_widget_set_no_show_all(panel->infobar, TRUE);
     gtk_widget_show(panel->infobar_label);
     gtk_widget_show(panel->infobar);
@@ -2006,9 +2014,11 @@ xfdesktop_settings_response(GtkWidget *dialog, gint response_id, gpointer user_d
 
 static GdkNativeWindow opt_socket_id = 0;
 static gboolean opt_version = FALSE;
+static gboolean opt_enable_debug = FALSE;
 static GOptionEntry option_entries[] = {
     { "socket-id", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_INT, &opt_socket_id, N_("Settings manager socket"), N_("SOCKET ID") },
     { "version", 'V', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &opt_version, N_("Version information"), NULL },
+    { "enable-debug", 'e', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &opt_enable_debug, N_("Enable debug messages"), NULL },
     { NULL, },
 };
 
@@ -2047,7 +2057,7 @@ main(int argc, char **argv)
 
     if(G_UNLIKELY(opt_version)) {
         g_print("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, VERSION, xfce_version_string());
-        g_print("%s\n", "Copyright (c) 2004-2013");
+        g_print("%s\n", "Copyright (c) 2004-2015");
         g_print("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print(_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print("\n");
@@ -2079,6 +2089,9 @@ main(int argc, char **argv)
 
     channel = xfconf_channel_new(XFDESKTOP_CHANNEL);
 
+    if(opt_enable_debug)
+        xfdesktop_debug_set(TRUE);
+
     if(opt_socket_id == 0) {
         GtkWidget *dialog;
         dialog = GTK_WIDGET(gtk_builder_get_object(gxml, "prefs_dialog"));
