@@ -467,7 +467,8 @@ xfdesktop_file_utils_add_emblems(GdkPixbuf *pix, GList *emblems)
     /* render up to four emblems for sizes from 48 onwards, else up to 2 emblems */
     max_emblems = (pix_height < 48 && pix_width < 48) ? 2 : 4;
 
-    for(iter = emblems, position = 0; iter != NULL && position < max_emblems; iter = iter->next) {
+    for(iter = g_list_last(emblems), position = 0;
+        iter != NULL && position < max_emblems; iter = iter->prev) {
         /* extract the icon from the emblem and load it */
         GIcon *emblem = g_emblem_get_icon(iter->data);
         GtkIconInfo *icon_info = gtk_icon_theme_lookup_by_gicon(itheme,
@@ -503,13 +504,13 @@ xfdesktop_file_utils_add_emblems(GdkPixbuf *pix, GList *emblems)
                     dest_x = 0;
                     dest_y = dest_height;
                     break;
-                case 2: /* upper right */
+                case 2: /* upper left */
+                    dest_x = dest_y = 0;
+                    break;
+                case 3: /* upper right */
                     dest_x = dest_width;
                     dest_y = 0;
                     break;
-                case 3: /* upper left */
-                    dest_x = dest_y = 0;
-                    break;
                 default:
                     g_warning("Invalid emblem position in xfdesktop_file_utils_add_emblems");
             }
@@ -781,38 +782,54 @@ xfdesktop_file_utils_bulk_rename(GFile *working_directory,
     }
 }
 
-static void
-delete_files(gpointer data, gpointer user_data)
-{
-    if(data == NULL)
-        return;
-
-    if(!G_IS_FILE(data))
-        return;
-
-    g_file_delete_async(G_FILE(data), G_PRIORITY_DEFAULT, NULL, NULL, NULL);
-}
-
-static void
-trash_files(gpointer data, gpointer user_data)
-{
-    if(data == NULL)
-        return;
-
-    if(!G_IS_FILE(data))
-        return;
-
-    g_file_trash_async(G_FILE(data), G_PRIORITY_DEFAULT, NULL, NULL, NULL);
-}
-
 void
 xfdesktop_file_utils_unlink_files(GList *files,
                                   GdkScreen *screen,
                                   GtkWindow *parent)
 {
-    g_return_if_fail(files != NULL && G_IS_FILE(files->data));
+    DBusGProxy *fileman_proxy;
 
-    g_list_foreach(files, (GFunc)delete_files, NULL);
+    g_return_if_fail(files != NULL && G_IS_FILE(files->data));
+    g_return_if_fail(GDK_IS_SCREEN(screen) || GTK_IS_WINDOW(parent));
+
+    if(!screen)
+        screen = gtk_widget_get_screen(GTK_WIDGET(parent));
+
+    fileman_proxy = xfdesktop_file_utils_peek_filemanager_proxy();
+    if(fileman_proxy) {
+        guint nfiles = g_list_length(files);
+        gchar **uris = g_new0(gchar *, nfiles+1);
+        gchar *display_name = gdk_screen_make_display_name(screen);
+        gchar *startup_id = g_strdup_printf("_TIME%d", gtk_get_current_event_time());
+        GList *lp;
+        gint n;
+
+        /* convert GFile list into an array of URIs */
+        for(n = 0, lp = files; lp != NULL; ++n, lp = lp->next)
+            uris[n] = g_file_get_uri(lp->data);
+        uris[n] = NULL;
+
+        xfdesktop_file_utils_set_window_cursor(parent, GDK_WATCH);
+
+        xfdesktop_file_manager_proxy_unlink_files_async(fileman_proxy,
+                                                        NULL, (const gchar **)uris,
+                                                        display_name, startup_id,
+                                                        (xfdesktop_file_manager_proxy_unlink_files_reply)xfdesktop_file_utils_async_cb,
+                                                        parent);
+
+        xfdesktop_file_utils_set_window_cursor(parent, GDK_LEFT_PTR);
+
+        g_free(startup_id);
+        g_strfreev(uris);
+        g_free(display_name);
+    } else {
+        xfce_message_dialog(parent,
+                            _("Delete Error"), GTK_STOCK_DIALOG_ERROR,
+                            _("The selected files could not be deleted"),
+                            _("This feature requires a file manager service to "
+                              "be present (such as the one supplied by Thunar)."),
+                            GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT, NULL);
+    }
 }
 
 void
@@ -820,9 +837,49 @@ xfdesktop_file_utils_trash_files(GList *files,
                                  GdkScreen *screen,
                                  GtkWindow *parent)
 {
-    g_return_if_fail(files != NULL && G_IS_FILE(files->data));
+    DBusGProxy *trash_proxy;
 
-    g_list_foreach(files, (GFunc)trash_files, NULL);
+    g_return_if_fail(files != NULL && G_IS_FILE(files->data));
+    g_return_if_fail(GDK_IS_SCREEN(screen) || GTK_IS_WINDOW(parent));
+
+    if(!screen)
+        screen = gtk_widget_get_screen(GTK_WIDGET(parent));
+
+    trash_proxy = xfdesktop_file_utils_peek_trash_proxy();
+    if(trash_proxy) {
+        guint nfiles = g_list_length(files);
+        gchar **uris = g_new0(gchar *, nfiles+1);
+        gchar *display_name = gdk_screen_make_display_name(screen);
+        gchar *startup_id = g_strdup_printf("_TIME%d", gtk_get_current_event_time());
+        GList *lp;
+        gint n;
+
+        /* convert GFile list into an array of URIs */
+        for(n = 0, lp = files; lp != NULL; ++n, lp = lp->next)
+            uris[n] = g_file_get_uri(lp->data);
+        uris[n] = NULL;
+
+        xfdesktop_file_utils_set_window_cursor(parent, GDK_WATCH);
+
+        xfdesktop_trash_proxy_move_to_trash_async(trash_proxy,
+                                                  (const gchar **)uris,
+                                                  display_name, startup_id,
+                                                  (xfdesktop_trash_proxy_move_to_trash_reply)xfdesktop_file_utils_async_cb,
+                                                  parent);
+
+        xfdesktop_file_utils_set_window_cursor(parent, GDK_LEFT_PTR);
+
+        g_free(startup_id);
+        g_strfreev(uris);
+        g_free(display_name);
+    } else {
+        xfce_message_dialog(parent,
+                            _("Trash Error"), GTK_STOCK_DIALOG_ERROR,
+                            _("The selected files could not be moved to the trash"),
+                            _("This feature requires a trash service to "
+                              "be present (such as the one supplied by Thunar)."),
+                            GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT, NULL);
+    }
 }
 
 void
